@@ -30,8 +30,7 @@
 #  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
 #  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
 #  Vestibulum commodo. Ut rhoncus gravida arcu.
-from typing import Dict, Tuple, List,AnyStr
-
+from typing import Dict, Tuple, List, AnyStr
 
 DataText = 0  # 文本数据
 DataAudio = 1  # 音频数据
@@ -40,26 +39,40 @@ DataVideo = 3  # 视频数据
 
 Once = 3
 
+
 class DataListNode:
     def __init__(self):
-        self.key : AnyStr
-        self.data : AnyStr
+        self.key: AnyStr
+        self.data: AnyStr
         self.len = 0
         self.type = DataText
 
+
 class DataListCls:
     def __init__(self):
         self.list: List[DataListNode]
 
+    def get(self, key: str):
+        for d in self.list:
+            if d.key == key:
+                return d
+        return None
+
 
 class ResponseData:
     def __init__(self):
-        self.key : AnyStr
-        self.data : AnyStr
+        self.key: AnyStr
+        self.data: AnyStr
         self.len = 0
         self.type = DataText
         self.status = Once
 
+
 class Response:
     def __init__(self):
-        self.list: List[ResponseData]
\ No newline at end of file
+        self.list: List[ResponseData]
+        self.errCode = 0
+
+    def response_err(self, errCode: int):
+        self.errCode = errCode
+        return self
